diff --git a/mozilla/include/allxpstr.h b/mozilla/include/allxpstr.h
index ab303bb9de6..d3ba2e38f85 100644
--- a/mozilla/include/allxpstr.h
+++ b/mozilla/include/allxpstr.h
@@ -7903,12 +7903,12 @@ ResDef(MK_ACCESS_NO, XP_MSG_BASE + 1446,
/* the following PRVCY items are all strings used in html */
ResDef(PRVCY_HAS_A_POLICY, XP_MSG_BASE + 1450,
-"This site has declared a policy \
-for what it does with the information you give it.\n")
+"This site has a privacy policy file \
+in which it states what it does with the information that you submit to it.\n")
ResDef(PRVCY_HAS_NO_POLICY, XP_MSG_BASE + 1451,
-"This site has not declared a policy for what it does \
-with the information you give it.\n")
+"We could not find a privacy policy file from this site stating what it does \
+with the information you submit to it.\n")
ResDef(PRVCY_CANNOT_SET_COOKIES, XP_MSG_BASE + 1452,
"This site cannot store information (cookies) on your computer.\n")
@@ -7926,6 +7926,8 @@ ResDef(PRVCY_HAS_SET_COOKIES, XP_MSG_BASE + 1456,
"This site has stored some information \
on your computer.\n")
+ResDef(PRVCY_POLICY_FILE_NAME, XP_MSG_BASE + 1457,
+"/privacy_policy.html")
/* Related Links XP Strings */
diff --git a/mozilla/include/allxpstr.rc b/mozilla/include/allxpstr.rc
index ab303bb9de6..d3ba2e38f85 100644
--- a/mozilla/include/allxpstr.rc
+++ b/mozilla/include/allxpstr.rc
@@ -7903,12 +7903,12 @@ ResDef(MK_ACCESS_NO, XP_MSG_BASE + 1446,
/* the following PRVCY items are all strings used in html */
ResDef(PRVCY_HAS_A_POLICY, XP_MSG_BASE + 1450,
-"This site has declared a policy \
-for what it does with the information you give it.\n")
+"This site has a privacy policy file \
+in which it states what it does with the information that you submit to it.\n")
ResDef(PRVCY_HAS_NO_POLICY, XP_MSG_BASE + 1451,
-"This site has not declared a policy for what it does \
-with the information you give it.\n")
+"We could not find a privacy policy file from this site stating what it does \
+with the information you submit to it.\n")
ResDef(PRVCY_CANNOT_SET_COOKIES, XP_MSG_BASE + 1452,
"This site cannot store information (cookies) on your computer.\n")
@@ -7926,6 +7926,8 @@ ResDef(PRVCY_HAS_SET_COOKIES, XP_MSG_BASE + 1456,
"This site has stored some information \
on your computer.\n")
+ResDef(PRVCY_POLICY_FILE_NAME, XP_MSG_BASE + 1457,
+"/privacy_policy.html")
/* Related Links XP Strings */
diff --git a/mozilla/privacy/src/privacy.c b/mozilla/privacy/src/privacy.c
index efc87ed81f1..39858a40dbf 100644
--- a/mozilla/privacy/src/privacy.c
+++ b/mozilla/privacy/src/privacy.c
@@ -256,6 +256,8 @@ prvcy_checkStandardLocation_finished
Check for privacy policy at standard location
*/
+extern char* PRVCY_POLICY_FILE_NAME;
+
PUBLIC void
PRVCY_CheckStandardLocation(MWContext * context)
{
@@ -272,13 +274,15 @@ PRVCY_CheckStandardLocation(MWContext * context)
* This routine is called from the HTTP_DONE case of NET_ProcessHTTP. But
* that will be repeatedly called as long as we keep issuing an http request
* in this routine. So, to prevent looping, we will set privacy_policy_url
* to -1 to indicate that we already did the http request for privacy.html.
*/
entry->privacy_policy_url = (char*)(-1); /* prevents looping */
/* Create a URL for privacy.html */
privacyURL = NET_ParseURL(entry->address, GET_PROTOCOL_PART | GET_HOST_PART);
- StrAllocCat(privacyURL, "/privacy.html");
+ StrAllocCat(privacyURL, "/");
+ StrAllocCat(privacyURL, PRVCY_POLICY_FILE_NAME);
if (prvcy_inCache(privacyURL, &found)) {
if (found) {
entry->privacy_policy_url = privacyURL;
@@ -482,7 +486,6 @@ extern int PRVCY_NEEDS_PERMISSION_TO_SET_COOKIES;
extern int PRVCY_HAS_SET_COOKIES;
extern int PRVCY_HAS_NOT_SET_COOKIES;
-
#define BUFLEN 5000
#define FLUSH_BUFFER \
if (buffer) { \
@@ -272,13 +274,15 @@ PRVCY_CheckStandardLocation(MWContext * context)
* that will be repeatedly called as long as we keep issuing an http request
* in this routine. So, to prevent looping, we will set privacy_policy_url
- * to -1 to indicate that we already did the http request for privacy.html.
+ * to -1 to indicate that we already did the http request for
+ * privacy_policy.html.
*/
entry->privacy_policy_url = (char*)(-1); /* prevents looping */
@@ -272,13 +274,15 @@ PRVCY_CheckStandardLocation(MWContext * context)
*/
entry->privacy_policy_url = (char*)(-1); /* prevents looping */
- /* Create a URL for privacy.html */
+ /* Create a URL for privacy_policy.html */
privacyURL = NET_ParseURL(entry->address, GET_PROTOCOL_PART | GET_HOST_PART);